@@ -64,10 +64,6 @@ You can also look for information at:
 
 =over 4
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Test-Run-Plugin-ColorFileVerdicts>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Test-Run-Plugin-ColorFileVerdicts>
@@ -88,7 +84,7 @@ L<http://metacpan.org/releaseTest-Run-Plugin-ColorFileVerdicts>
 
 Copyright 2007 Shlomi Fish, all rights reserved.
 
-This program is released under the following license: MIT X11
+This program is released under the following license: MIT Expat
 
 =cut
 
